@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "modules/libpref/src/init/all.js"
+//@line 142 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "modules/libpref/src/init/all.js"
+//@line 145 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "modules/libpref/src/init/all.js"
+//@line 147 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -158,7 +158,7 @@ pref("gfx.downloadable_fonts.enabled", true);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 163 "modules/libpref/src/init/all.js"
+//@line 163 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -171,7 +171,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 179 "modules/libpref/src/init/all.js"
+//@line 179 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -519,9 +519,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 527 "modules/libpref/src/init/all.js"
+//@line 527 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 529 "modules/libpref/src/init/all.js"
+//@line 529 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -566,7 +566,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 576 "modules/libpref/src/init/all.js"
+//@line 576 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -799,7 +799,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 814 "modules/libpref/src/init/all.js"
+//@line 814 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -818,9 +818,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 834 "modules/libpref/src/init/all.js"
+//@line 834 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 841 "modules/libpref/src/init/all.js"
+//@line 841 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -838,7 +838,6 @@ pref("network.proxy.no_proxies_on",         "localhost, 127.0.0.1");
 pref("network.proxy.failover_timeout",      1800); // 30 minutes
 pref("network.online",                      true); //online/offline
 pref("network.cookie.cookieBehavior",       0); // 0-Accept, 1-dontAcceptForeign, 2-dontUse
-pref("network.cookie.disableCookieForMailNews", true); // disable all cookies for mail
 pref("network.cookie.lifetimePolicy",       0); // accept normally, 1-askBeforeAccepting, 2-acceptForSession,3-acceptForNDays
 pref("network.cookie.alwaysAcceptSessionCookies", false);
 pref("network.cookie.prefsMigrated",        false);
@@ -1183,15 +1182,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1582 "modules/libpref/src/init/all.js"
+//@line 1581 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 1999 "modules/libpref/src/init/all.js"
+//@line 1998 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2200 "modules/libpref/src/init/all.js"
+//@line 2199 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2294 "modules/libpref/src/init/all.js"
+//@line 2293 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2297 "modules/libpref/src/init/all.js"
+//@line 2296 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1459,15 +1458,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2567 "modules/libpref/src/init/all.js"
+//@line 2566 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2635 "modules/libpref/src/init/all.js"
+//@line 2634 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2661 "modules/libpref/src/init/all.js"
+//@line 2660 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2681 "modules/libpref/src/init/all.js"
+//@line 2680 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
-//@line 2689 "modules/libpref/src/init/all.js"
+//@line 2688 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1491,7 +1490,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2718 "modules/libpref/src/init/all.js"
+//@line 2717 "/icecat-3.5.6/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
